import {withCamera} from "./layout.ts";
import {D} from "./engine/public.ts";
import {FG_BOLD, FG_TEXT} from "./colors.ts";
import {AlignX, Point, Rect, Size} from "./engine/datatypes.ts";
import {DrawPile} from "./drawpile.ts";
import {addButton} from "./button.ts";

const WIDTH = 384;
const HEIGHT = 384;

export class EndgameModal {
  #isShown: boolean;
  #drawpile: DrawPile;

  constructor() {
    this.#isShown = false;
    this.#drawpile = new DrawPile();

    // debug
  }

  get isShown(): boolean {
    return this.#isShown;
  }

  show() {
    this.#isShown = true;
  }

  update() {
    withCamera("FullscreenPopover", () => this.#update())
  }

  draw() {
    withCamera("FullscreenPopover", () => this.#draw())
  }

  #update() {
    this.#drawpile.clear();
    addButton(
      this.#drawpile,
      "Appoint a Successor",
      new Rect(
        new Point(0, HEIGHT - 32), new Size(WIDTH, 32)
      ),
      true,
      () => {
        alert("beep");
      }
    )
    this.#drawpile.executeOnClick();
  }

  #draw() {
    D.drawText("It is time to announce the sentence of fate.", new Point(0, 0), FG_TEXT)
    D.drawText("You are no longer a fledgling. Your new rank:", new Point(0, 32), FG_TEXT)
    D.drawText("Progenitor", new Point(WIDTH/2, 64), FG_BOLD, {alignX: AlignX.Center})
    D.drawText("You have achieved a DOMICILE STATUS of:", new Point(0, 96), FG_TEXT)
    D.drawText("Guest House", new Point(WIDTH/2, 128), FG_BOLD, {alignX: AlignX.Center})
    D.drawText("where you live with many friends.", new Point(0, 160), FG_TEXT)
    D.drawText("You have achieved:", new Point(0, 192), FG_TEXT)
    D.drawText("48 items purloined\n96 vampiric skills\n50 mortal servants", new Point(WIDTH/2, 224), FG_TEXT, {alignX: AlignX.Center})
    D.drawText("48                \n96                \n50                ", new Point(WIDTH/2, 224), FG_BOLD, {alignX: AlignX.Center})
    D.drawText("That feels like a lot!", new Point(0, 288), FG_TEXT)
    D.drawText("Your reign continues unimpeded from the shadows. It is now time to", new Point(0, 320), FG_TEXT, {forceWidth: WIDTH})

    this.#drawpile.draw();
  }

  get blocksHud(): boolean {
    return true;
  }
}

let active = new EndgameModal();
export function getEndgameModal() {
  return active;
}